@@ -38,9 +38,6 @@
 #include <stdlib.h>
 #include <math.h>
 #include <time.h>
-#if defined(__IBMC__)
-#include <float.h>
-#endif
 #if defined(DEBUG) || defined(DUMP_PLOT)
 # include "plot.h"
 # include "ui.h"
@@ -198,7 +195,7 @@ double off,		/* Starting offset in device space */
 double angle	/* Rotation angle 0.0 - 1.0 */
 ) {
 	int  i, j, di = s->di;
-	double sx[MXTD+1][MXTD];	/* Simplex verticies */
+	double sx[MXTD+1][MXTD];	/* Simplex vertices */
 
 	switch (type) {
 
@@ -304,7 +301,7 @@ double angle	/* Rotation angle 0.0 - 1.0 */
 		}
 	}
 
-#ifdef DEBUG	/* Dump stats on verticies */
+#ifdef DEBUG	/* Dump stats on vertices */
 for(i = 0; i < (di+1); i++) {
 	double val = 0.0;
 	printf("vert %d = ",i);
@@ -331,7 +328,7 @@ for(i = 0; i < di; i++) {
 }
 #endif	/* DEBUG */
 
-	/* Convert from di+1 verticies to di base vectors */
+	/* Convert from di+1 vertices to di base vectors */
 	for (i = 0; i < di; i++) {
 		for (j = 0; j < di; j++) {
 			s->bv[i][j] = sx[i+1][j] - sx[i][j];
@@ -708,11 +705,6 @@ void *od				/* context for Perceptual function */
 	if ((s = (simdlat *)calloc(sizeof(simdlat), 1)) == NULL)
 		error ("simdlat: simdlat malloc failed");
 
-#if defined(__IBMC__)
-	_control87(EM_UNDERFLOW, EM_UNDERFLOW);
-	_control87(EM_OVERFLOW, EM_OVERFLOW);
-#endif
-
 	s->reset = simdlat_reset;
 	s->read  = simdlat_read;
 	s->del   = simdlat_del;
